@@ -172,7 +172,7 @@ def run_pca_ancestry_analysis(
     sample_to_drop_ht: Optional[hl.Table],
     tmp_bucket: str,
     n_pcs: int,
-    out_eigenvalues_ht_path: Optional[str] = None,
+    out_eigenvalues_path: Optional[str] = None,
     out_scores_ht_path: Optional[str] = None,
     out_loadings_ht_path: Optional[str] = None,
     overwrite: bool = False,
@@ -185,7 +185,7 @@ def run_pca_ancestry_analysis(
         previous relatedness analysis. With a `rank` row field
     :param n_pcs: maximum number of principal components
     :param overwrite: overwrite checkpoints if they exist
-    :param out_eigenvalues_ht_path: path to write PCA eigenvalues
+    :param out_eigenvalues_path: path to a txt file to write PCA eigenvalues
     :param out_scores_ht_path: path to write PCA scores
     :param out_loadings_ht_path: path to write PCA loadings
     :return: a Table with a row field:
@@ -196,7 +196,7 @@ def run_pca_ancestry_analysis(
     if all(
         not fp or utils.can_reuse(fp, overwrite)
         for fp in [
-            out_eigenvalues_ht_path,
+            out_eigenvalues_path,
             out_scores_ht_path,
             out_loadings_ht_path,
         ]
@@ -211,8 +211,8 @@ def run_pca_ancestry_analysis(
         mt, sample_to_drop_ht, n_pcs=n_pcs
     )
 
-    if out_eigenvalues_ht_path:
-        hl.Table.from_pandas(pd.DataFrame(eigenvalues)).export(out_eigenvalues_ht_path)
+    if out_eigenvalues_path:
+        hl.Table.from_pandas(pd.DataFrame(eigenvalues)).export(out_eigenvalues_path)
     if out_loadings_ht_path:
         loadings_ht.write(out_loadings_ht_path, overwrite=True)
     scores_ht.write(out_scores_ht_path, overwrite=True)
@@ -220,9 +220,9 @@ def run_pca_ancestry_analysis(
     return scores_ht
 
 
-def assign_pops(
+def infer_pop_labels(
     pop_pca_scores_ht: hl.Table,
-    assigned_pop_ht: hl.Table,
+    provided_pop_ht: hl.Table,
     tmp_bucket: str,
     min_prob: float,
     max_mislabeled_training_samples: int = 50,
@@ -236,7 +236,7 @@ def assign_pops(
 
     :param pop_pca_scores_ht: output table of `_run_pca_ancestry_analysis()`
         with a row field 'scores': array<float64>
-    :param assigned_pop_ht: table with a `continental_pop` field. Samples for which
+    :param provided_pop_ht: table with a `continental_pop` field. Samples for which
         the latter is defined will be used to train the random forest
     :param tmp_bucket: bucket to write checkpoints and intermediate files
     :param min_prob: min probability of belonging to a given population
@@ -256,13 +256,13 @@ def assign_pops(
         ... (prob_*: float64 for each population label)
     """
     logger.info('Assigning global population labels')
-    out_ht_path = out_ht_path or join(tmp_bucket, 'pop.ht')
+    out_ht_path = out_ht_path or join(tmp_bucket, 'inferred_pop.ht')
     if utils.can_reuse(out_ht_path, overwrite):
         return hl.read_table(out_ht_path)
 
-    samples_with_pop_ht = assigned_pop_ht.filter(
-        hl.is_defined(assigned_pop_ht.continental_pop) & assigned_pop_ht.continental_pop
-        != ''
+    samples_with_pop_ht = provided_pop_ht.filter(
+        hl.is_defined(provided_pop_ht.continental_pop)
+        & (provided_pop_ht.continental_pop != '')
     )
     pop_pca_scores_ht = pop_pca_scores_ht.annotate(
         training_pop=samples_with_pop_ht[pop_pca_scores_ht.key].continental_pop
