@@ -7,13 +7,15 @@ import logging
 import sys
 import time
 import hashlib
-from os.path import isdir, isfile, exists, join
-from typing import Any, Callable, Dict, Optional
+from os.path import isdir, isfile, exists, join, basename
+from typing import Any, Callable, Dict, Optional, Union, Iterable
 import yaml
+import pandas as pd
 import hail as hl
 import click
 from google.cloud import storage
 from joint_calling import _version, get_package_path
+from joint_calling import __name__ as package_name
 
 
 logger = logging.getLogger(__file__)
@@ -46,7 +48,11 @@ GATK_IMAGE = f'{AR_REPO}/gatk:{GATK_VERSION}'
 GNARLY_IMAGE = f'{AR_REPO}/gnarly_genotyper:hail_ukbb_300K'
 BCFTOOLS_IMAGE = f'{AR_REPO}/bcftools:1.10.2--h4f4756c_2'
 SM_IMAGE = f'{AR_REPO}/sm-api:2.0.3'
+ALIGNMENT_IMAGE = f'{AR_REPO}/alignment:v4'
+PICARD_IMAGE = f'{AR_REPO}/picard-cloud:2.23.8'
 
+REF_FASTA = join(REF_BUCKET, 'Homo_sapiens_assembly38.fasta')
+UNPADDED_INTERVALS = join(REF_BUCKET, 'hg38.even.handcurated.20k.intervals')
 NOALT_REGIONS = join(REF_BUCKET, 'noalt.bed')
 TEL_AND_CENT_HT_PATH = join(
     REF_BUCKET, 'gnomad/telomeres_and_centromeres/hg38.telomeresAndMergedCentromeres.ht'
@@ -60,29 +66,28 @@ CLINVAR_HT_PATH = join(REF_BUCKET, 'gnomad/clinvar/clinvar_20190923.ht')
 GNOMAD_HT_PATH = (
     'gs://gcp-public-data--gnomad/release/3.1/ht/genomes/gnomad.genomes.v3.1.sites.ht/'
 )
-GNOMAD_HGDP_1KG_MT_PATH = (
-    'gs://gcp-public-data--gnomad/release/3.1/mt/genomes/'
-    'gnomad.genomes.v3.1.hgdp_1kg_subset_dense.mt'
-)
+
+GNOMAD_HGDP_FOR_PCA = {
+    'all': 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_hq.mt',
+    'nfe': 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_nfe_hq.mt',
+    'test': 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_test_hq.mt',
+    'test_nfe': 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_test_nfe_hq.mt',
+}
+
 GNOMAD_HGDP_1KG_TEST_MT_PATH = join(
+    REF_BUCKET, 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_test_hq.mt'
+)
+GNOMAD_HGDP_1KG_TEST_NFE_MT_PATH = join(
     REF_BUCKET, 'mt/gnomad.genomes.v3.1.hgdp_1kg_subset_dense_test.mt'
 )
 
+SCRIPTS_DIR = 'scripts'
+PACKAGE_DIR = package_name
 
 NUMBER_OF_HAPLOTYPE_CALLER_INTERVALS = 50
 NUMBER_OF_GENOMICS_DB_INTERVALS = 50
 
 
-# Sample QC output file names
-POP_HT_NAME = 'pop.ht'
-REGRESSED_METRICS_HT_NAME = 'regressed_metrics.ht'
-RELATED_SAMPLES_TO_DROP_HT_NAME = 'related_samples_to_drop.ht'
-
-PCA_EIGENVALUES_HT_NAME = 'pca_eigenvalues.ht'
-PCA_SCORES_HT_NAME = 'pca_scores.ht'
-PCA_LOADINGS_HT_NAME = 'pca_loadings.ht'
-
-
 def init_hail(name: str, local_tmp_dir: str = None):
     """
     Initialize Hail and set up the directory for logs
@@ -167,12 +172,23 @@ def file_exists(path: str) -> bool:
     return os.path.exists(path)
 
 
-def can_reuse(fpath: Optional[str], overwrite: bool, silent=False) -> bool:
+def can_reuse(
+    fpath: Optional[Union[Iterable[str], str]],
+    overwrite: bool,
+    silent=False,
+) -> bool:
     """
-    Checks if the file `fpath` exists and we are not overwriting
+    Checks if `fpath` is good to reuse in the analysis: it exists
+    and `overwrite` is False.
+
+    If `fpath` is a collection, it requires all files in it to exist.
     """
     if not fpath:
         return False
+
+    if not isinstance(fpath, str):
+        return all(can_reuse(fp, overwrite) for fp in fpath)
+
     if not file_exists(fpath):
         return False
 
@@ -353,3 +369,23 @@ def get_filter_cutoffs(
             filter_cutoffs_d = yaml.safe_load(f)
 
     return filter_cutoffs_d
+
+
+def parse_input_metadata(
+    meta_csv_path: str,
+    local_tmp_dir: str,
+    out_ht_path: Optional[str] = None,
+) -> hl.Table:
+    """
+    Parse KCCG metadata (population and picard metrics)
+    """
+    local_csv_path = join(local_tmp_dir, basename(meta_csv_path))
+    subprocess.run(
+        f'gsutil cp {meta_csv_path} {local_csv_path}', check=False, shell=True
+    )
+
+    df = pd.read_table(local_csv_path)
+    ht = hl.Table.from_pandas(df).key_by('s')
+    if out_ht_path:
+        ht = ht.checkpoint(out_ht_path, overwrite=True)
+    return ht
