@@ -7,6 +7,7 @@ Plot ancestry PCA analysis results
 import logging
 import click
 import pandas as pd
+import numpy as np
 import hail as hl
 from bokeh.io.export import get_screenshot_as_png
 from bokeh.resources import CDN
@@ -28,10 +29,10 @@ logger.setLevel(logging.INFO)
 @click.command()
 @click.version_option(_version.__version__)
 @click.option(
-    '--eigenvalues-ht',
-    'eigenvalues_ht_path',
+    '--eigenvalues',
+    'eigenvalues_path',
     required=True,
-    callback=utils.get_validation_callback(ext='ht', must_exist=True),
+    callback=utils.get_validation_callback(ext='txt', must_exist=True),
 )
 @click.option(
     '--scores-ht',
@@ -59,7 +60,7 @@ logger.setLevel(logging.INFO)
     help='Hail billing account ID.',
 )
 def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function-docstring
-    eigenvalues_ht_path: str,
+    eigenvalues_path: str,
     scores_ht_path: str,
     loadings_ht_path: str,
     assigned_pop_ht_path: str,
@@ -69,7 +70,7 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     utils.init_hail(__file__)
 
     produce_plots(
-        eigenvalues_ht_path=eigenvalues_ht_path,
+        eigenvalues_path=eigenvalues_path,
         scores_ht_path=scores_ht_path,
         loadings_ht_path=loadings_ht_path,
         assigned_pop_ht_path=assigned_pop_ht_path,
@@ -78,7 +79,7 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
 
 
 def produce_plots(
-    eigenvalues_ht_path: str,
+    eigenvalues_path: str,
     scores_ht_path: str,
     loadings_ht_path: str,
     assigned_pop_ht_path: str,
@@ -89,9 +90,6 @@ def produce_plots(
     scope ("study", "continental_pop", "subpop", plus for loadings) into
     file paths defined by `out_path_pattern`.
     """
-
-    utils.init_hail(__file__)
-
     assigned_pop_ht = hl.read_table(assigned_pop_ht_path)
     scores = hl.read_table(scores_ht_path)
     scores = scores.annotate(study=assigned_pop_ht[scores.s].project)
@@ -99,18 +97,18 @@ def produce_plots(
     labels = scores.study.collect()
     study = list(set(labels))
     tooltips = [('labels', '@label'), ('samples', '@samples')]
-    eigenvalues = hl.import_table(eigenvalues_ht_path)
-    eigenvalues = eigenvalues.to_pandas()
-    eigenvalues.columns = ['eigenvalue']
-    eigenvalues = pd.to_numeric(eigenvalues.eigenvalue)
-    variance = eigenvalues.divide(float(eigenvalues.sum())) * 100
+    eigenvalues = hl.import_table(
+        eigenvalues_path, no_header=True, types={'f0': hl.tfloat}
+    ).f0.collect()
+    eigenvalues = pd.to_numeric(eigenvalues)
+    variance = np.divide(eigenvalues[1:], float(eigenvalues.sum())) * 100
     variance = variance.round(2)
 
     # Get number of PCs
-    number_of_pcs = len(eigenvalues)
+    number_of_pcs = len(eigenvalues) - 1
 
     # plot by study
-    for i in range(0, (number_of_pcs - 1)):
+    for i in range(number_of_pcs - 1):
         pc1 = i
         pc2 = i + 1
         plot = figure(
@@ -148,12 +146,11 @@ def produce_plots(
     # plot by continental population
     scores = scores.annotate(continental_pop=assigned_pop_ht[scores.s].continental_pop)
     labels = scores.continental_pop.collect()
-    # Change TOB-WGS 'none' values to 'TOB-WGS'
-    labels = ['TOB-NFE' if x is None else x for x in labels]
+    labels = [(x or 'missing') for x in labels]
     continental_population = list(set(labels))
     tooltips = [('labels', '@label'), ('samples', '@samples')]
 
-    for i in range(0, (number_of_pcs - 1)):
+    for i in range(number_of_pcs - 1):
         pc1 = i
         pc2 = i + 1
         plot = figure(
@@ -197,11 +194,11 @@ def produce_plots(
     # plot by subpopulation
     scores = scores.annotate(subpop=assigned_pop_ht[scores.s].subpop)
     labels = scores.subpop.collect()
-    labels = ['TOB-NFE' if x is None else x for x in labels]
+    labels = [(x or 'missing') for x in labels]
     sub_population = list(set(labels))
     tooltips = [('labels', '@label'), ('samples', '@samples')]
 
-    for i in range(0, (number_of_pcs - 1)):
+    for i in range(number_of_pcs - 1):
         pc1 = i
         pc2 = i + 1
         plot = figure(
@@ -240,7 +237,7 @@ def produce_plots(
 
     # Plot loadings
     loadings_ht = hl.read_table(loadings_ht_path)
-    for i in range(0, number_of_pcs):
+    for i in range(number_of_pcs - 1):
         pc = i + 1
         plot = manhattan_loadings(
             pvals=hl.abs(loadings_ht.loadings[i]),
