@@ -27,7 +27,7 @@ logger.setLevel(logging.INFO)
     'pca_mt_path',
     required=True,
     callback=utils.get_validation_callback(ext='mt', must_exist=True),
-    help='path to the Matrix Table ready for PC relate',
+    help='path to the Matrix Table ready for PC relate. Dense and GT-annotated',
 )
 @click.option(
     '--out-relatedness-ht',
@@ -59,8 +59,10 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     overwrite: bool,
     hail_billing: str,  # pylint: disable=unused-argument
 ):
+    utils.init_hail(__file__)
+
     mt = hl.read_matrix_table(pca_mt_path)
-    mt = mt.select_entries('END', GT=mt.LGT)
+    mt = mt.select_entries('GT')
 
     _compute_relatedness(
         mt=mt,
