@@ -39,10 +39,10 @@ logger.setLevel(logging.INFO)
     help='path to the Matrix Table',
 )
 @click.option(
-    '--input-metadata-ht',
-    'input_metadata_ht_path',
+    '--meta-csv',
+    'meta_csv_path',
     required=True,
-    callback=utils.get_validation_callback(ext='ht', must_exist=True),
+    help='path to a CSV with QC and population metadata for the samples',
 )
 @click.option(
     '--pre-computed-hgdp-union-mt',
@@ -58,8 +58,8 @@ logger.setLevel(logging.INFO)
     'The difference with `--out-mt` is that it also contains HGDP-1KG samples',
 )
 @click.option(
-    '--out-assigned-pop-ht',
-    'out_assigned_pop_ht_path',
+    '--out-provided-pop-ht',
+    'out_provided_pop_ht_path',
     callback=utils.get_validation_callback(ext='ht'),
     help='writes table with 3 column fields: continental_pop, subpop, study',
 )
@@ -72,6 +72,10 @@ logger.setLevel(logging.INFO)
     'The difference with --out-hgdp-union-mt is that it contains only the dataset '
     'samples',
 )
+@click.option(
+    '--pop',
+    'pop',
+)
 @click.option(
     '--overwrite/--reuse',
     'overwrite',
@@ -93,19 +97,30 @@ logger.setLevel(logging.INFO)
 )
 def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function-docstring
     mt_path: str,
-    input_metadata_ht_path: str,
+    meta_csv_path: str,
     pre_computed_hgdp_unuon_mt_path: Optional[str],
     out_hgdp_union_mt_path: str,
-    out_assigned_pop_ht_path: str,
+    out_provided_pop_ht_path: str,
     out_mt_path: str,
+    pop: Optional[str],
     overwrite: bool,
     is_test: bool,  # pylint: disable=unused-argument
     hail_billing: str,  # pylint: disable=unused-argument
 ):
-    utils.init_hail(__file__)
+    local_tmp_dir = utils.init_hail(__file__)
 
-    input_metadata_ht = hl.read_table(input_metadata_ht_path)
-    hgdp_mt = hl.read_matrix_table(utils.GNOMAD_HGDP_1KG_MT_PATH)
+    input_metadata_ht = utils.parse_input_metadata(meta_csv_path, local_tmp_dir)
+
+    if pop and pop in utils.GNOMAD_HGDP_FOR_PCA:
+        if is_test:
+            hgdp_mt = hl.read_matrix_table(utils.GNOMAD_HGDP_FOR_PCA[f'test_{pop}'])
+        else:
+            hgdp_mt = hl.read_matrix_table(utils.GNOMAD_HGDP_FOR_PCA[pop])
+    else:
+        if is_test:
+            hgdp_mt = hl.read_matrix_table(utils.GNOMAD_HGDP_FOR_PCA['test'])
+        else:
+            hgdp_mt = hl.read_matrix_table(utils.GNOMAD_HGDP_FOR_PCA['all'])
 
     mt = utils.get_mt(mt_path, passing_sites_only=True)
     # Subset to biallelic SNPs in autosomes
@@ -121,19 +136,17 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     if pre_computed_hgdp_unuon_mt_path:
         hgdp_union_mt = hl.read_matrix_table(pre_computed_hgdp_unuon_mt_path)
     else:
-        # if is_test:
-        #     hgdp_mt = hl.read_matrix_table(utils.GNOMAD_HGDP_1KG_TEST_MT_PATH)
         hgdp_union_mt = get_sites_shared_with_hgdp(
             mt=mt,
             hgdp_mt=hgdp_mt,
             overwrite=overwrite,
         )
 
-    _make_assigned_pop_ht(
+    _make_provided_pop_ht(
         hgdp_union_mt=hgdp_union_mt,
         input_metadata_ht=input_metadata_ht,
         hgdp_ht=hgdp_mt.cols(),
-        out_assigned_pop_ht_path=out_assigned_pop_ht_path,
+        out_provided_pop_ht_path=out_provided_pop_ht_path,
         overwrite=overwrite,
     )
 
@@ -150,31 +163,28 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     )
 
 
-def _make_assigned_pop_ht(
+def _make_provided_pop_ht(
     hgdp_union_mt: hl.MatrixTable,
     input_metadata_ht: hl.Table,
     hgdp_ht: hl.Table,
-    out_assigned_pop_ht_path: str,
+    out_provided_pop_ht_path: str,
     overwrite: bool,
 ) -> hl.Table:
-    if utils.can_reuse(out_assigned_pop_ht_path, overwrite):
-        return hl.read_table(out_assigned_pop_ht_path)
+    if utils.can_reuse(out_provided_pop_ht_path, overwrite):
+        return hl.read_table(out_provided_pop_ht_path)
     ht = hgdp_union_mt.cols().select_globals().select()
     ht = ht.annotate(
         project=hl.case()
         .when(hl.is_defined(hgdp_ht[ht.s]), 'gnomad')
-        .default('tob-wgs'),
-        # .default(input_metadata_ht[ht.s].project),
+        .default(input_metadata_ht[ht.s].project),
         continental_pop=hl.case()
         .when(hl.is_defined(hgdp_ht[ht.s]), hgdp_ht[ht.s].population_inference.pop)
-        .default(''),
-        # .default(input_metadata_ht[ht.s].continental_pop),
+        .default(input_metadata_ht[ht.s].continental_pop),
         subpop=hl.case()
         .when(hl.is_defined(hgdp_ht[ht.s]), hgdp_ht[ht.s].labeled_subpop)
-        .default(''),
-        # .default(input_metadata_ht[ht.s].subpop),
+        .default(input_metadata_ht[ht.s].subpop),
     )
-    return ht.checkpoint(out_assigned_pop_ht_path, overwrite=overwrite)
+    return ht.checkpoint(out_provided_pop_ht_path, overwrite=overwrite)
 
 
 def get_sites_shared_with_hgdp(
