@@ -25,33 +25,38 @@ logger.setLevel(logging.INFO)
 @click.command()
 @click.version_option(_version.__version__)
 @click.option(
-    '--input-metadata-ht',
-    'input_metadata_ht_path',
-    callback=utils.get_validation_callback(ext='ht', must_exist=True),
+    '--meta-csv',
+    'meta_csv_path',
+    required=True,
+    help='path to a CSV with QC and population metadata for the samples',
 )
 @click.option(
     '--hard-filtered-samples-ht',
     'hard_filtered_samples_ht_path',
+    required=True,
+    callback=utils.get_validation_callback(ext='ht', must_exist=True),
+)
+@click.option(
+    '--hail-sample-qc-ht',
+    'hail_sample_qc_ht_path',
+    required=True,
     callback=utils.get_validation_callback(ext='ht', must_exist=True),
 )
 @click.option(
     '--sex-ht',
     'sex_ht_path',
+    required=True,
     callback=utils.get_validation_callback(ext='ht', must_exist=True),
 )
 @click.option(
     '--custom-qc-ht',
     'custom_qc_ht_path',
+    required=True,
     callback=utils.get_validation_callback(ext='ht', must_exist=True),
 )
 @click.option(
     '--regressed-filtes-ht',
     'regressed_metrics_ht_path',
-    callback=utils.get_validation_callback(ext='ht', must_exist=True),
-)
-@click.option(
-    '--hard-filtered-samples-ht',
-    'hard_filtered_samples_ht_path',
     required=True,
     callback=utils.get_validation_callback(ext='ht', must_exist=True),
 )
@@ -105,11 +110,11 @@ logger.setLevel(logging.INFO)
     help='Hail billing account ID.',
 )
 def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function-docstring
-    input_metadata_ht_path: str,
+    meta_csv_path: str,
     hard_filtered_samples_ht_path: str,
+    hail_sample_qc_ht_path: str,
     sex_ht_path: str,
     custom_qc_ht_path: str,
-    hail_sample_qc_ht_path: str,
     regressed_metrics_ht_path: str,
     relatedness_ht_path: str,
     pop_ht_path: str,
@@ -121,11 +126,11 @@ def main(  # pylint: disable=too-many-arguments,too-many-locals,missing-function
     overwrite: bool,
     hail_billing: str,  # pylint: disable=unused-argument
 ):
-    utils.init_hail(__file__)
+    local_tmp_dir = utils.init_hail(__file__)
 
     cutoffs_d = utils.get_filter_cutoffs(filter_cutoffs_path)
 
-    input_metadata_ht = hl.read_table(input_metadata_ht_path)
+    input_metadata_ht = utils.parse_input_metadata(meta_csv_path, local_tmp_dir)
     hard_filtered_samples_ht = hl.read_table(hard_filtered_samples_ht_path)
     sex_ht = hl.read_table(sex_ht_path)
     custom_qc_ht = hl.read_table(custom_qc_ht_path)
